@@ -128,7 +128,7 @@ diagtest <- function(table,positive=2,exact=FALSE,p0=NA,confint=c("logit","arcsi
         names(dimnames(table)) <- paste0(c("Test:","Outcome:"),names(dimnames(table)))
         prfun <- function(x,...) {
             printCoefmat(x$coefmat[,c(-2)],na.print="",...)
-            printline()
+            print(cli::rule())
             cat("\n")
             cat("Prevalence:				Prob( outcome+ )\n")
             cat("Test:					Prob( test+ )\n")
@@ -179,13 +179,13 @@ diagtest <- function(table,positive=2,exact=FALSE,p0=NA,confint=c("logit","arcsi
 print.diagtest <- function(x,...) {
     cat("Call: "); print(x$call)
     cat("Confidence limits: ", x$confint,"\n",sep="")
-    printline()
+    print(cli::rule())
     printmany(x$table,x$prop.table,nspace=2,...)
     cat("\nPositive outcome: '", x$levels[[2]][x$positive],"'\n",sep="")
-    ##cat("\tNegative outcome: '", x$levels[[2]][x$positive%%2+1],"'\n",sep="")
-    printline()
+    ## cat("\tNegative outcome: '", x$levels[[2]][x$positive%%2+1],"'\n",sep="")
+    print(cli::rule())
     printCoefmat(x$coefmat[,c(-2)],na.print="",...)
-    printline()
+    print(cli::rule())
     cat("\n")
     cat("Prevalence:				Prob( outcome+ )\n")
     cat("Test:					Prob( test+ )\n")
@@ -202,7 +202,7 @@ print.diagtest <- function(x,...) {
     cat("\n")
 }
 
-summary.diagtest <- function(x,...) {
-    x[c("IC","print","id","compare")] <- NULL
-    return(x)
+summary.diagtest <- function(object, ...) {
+    object[c("IC","print","id","compare")] <- NULL
+    return(object)
 }
