@@ -1,9 +1,3 @@
-char2num <- function(x,...) {
-    idx <- grep("^[-]*[0-9\\.]+",x,perl=TRUE,invert=TRUE)
-    if (length(idx)>0) x[idx] <- NA
-    as.numeric(x)
-}
-
 ###{{{ substArg
 
 substArg <- function(x,env,...) {
@@ -425,7 +419,6 @@ Decomp.specials <- function(x,pattern="[()]") {
 
 }
 
-printline <- function(n=70) {
-    cat(rep("_", n), "\n", sep="");
-
+printline <- function(n=getOption("width"), sep="\u2500") {
+    cat(rep(sep, n), "\n", sep="")
 }
